@@ -10,7 +10,7 @@ const project = new cdk.JsiiProject({
   codeCov: true,
 
   release: true,
-
+  publishTasks: true,
   publishToPypi: {
     distName: 'lazy-constructs',
     module: 'lazy_constructs',
@@ -21,7 +21,11 @@ const project = new cdk.JsiiProject({
     mavenGroupId: 'com.lazinessdevs',
     mavenEndpoint: 'https://s01.oss.sonatype.org',
   },
-  publishTasks: true,
+  publishToNuget: {
+    dotNetNamespace: 'Lazinessdevs.Lazy',
+    packageId: 'Lazyconstructs',
+  },
+
 
   peerDeps: [
     'constructs@^10.0.5',
